import phonenumbers

from id_phonenumbers.data import (AREA_CODE, CDMA_PREFIXES,
                                  GSM_PREFIXES, MOBILE_CDMA_PREFIXES)


class Number(object):

    def __init__(self, phone):
        self.phone = phone
        self._phone = phonenumbers.parse(self.phone, "ID")

        self.national_number = str(self._phone.national_number)
        self.local_number = None

        self.carrier = None
        self.area_code = None
        self.area_name = None
        self.is_mobile = False

        self.parse()

    def __unicode__(self):
        return "%s" % self.__dict__

    def parse_area_code(self):
        if self.phone:
            # Test for 3-number area code
            self.area_name = AREA_CODE.get(self.national_number[:3])
            if self.area_name is not None:
                self.area_code = self.national_number[:3]
                self.local_number = self.national_number[3:]

            # Test for 2-number area code
            else:
                self.area_name = AREA_CODE.get(self.national_number[:2])
                if self.area_name:
                    self.area_code = self.national_number[:2]
                    self.local_number = self.national_number[2:]

            # If cannot determine Area Name,  assume given number is local number
            if self.area_name is None:
                self.local_number = self.national_number

        return None

    def parse(self):
        self.parse_area_code()

        number_length = len(self.local_number)

        # Check if this is a fixed CDMA number
        if number_length == 10 or number_length == 11:
            self.carrier = MOBILE_CDMA_PREFIXES.get(self.local_number[:3])

        # GSM prefix always have 10 to 12 number length.
        if self.carrier is None and number_length in (9, 10, 11):
            self.carrier = GSM_PREFIXES.get(self.local_number[:3])

        # Try to check CDMA prefix, always have 8 number length
        if self.carrier is None and number_length == 8:
            self.carrier = CDMA_PREFIXES.get(self.local_number[:2]) \
                or CDMA_PREFIXES.get(self.local_number[:1])

        if self.carrier:
            self.is_mobile = True



CDMA_PREFIXES = {

    "9": "Esia",  # (Area-Code) - 9xxx-xxxx
    "80": "Esia",  # 021 - 80xx-xxxx
    "83": "Esia",  # 021-83xx-xxxx

    "54": "TelkomFlexi",  # (area-code)-54xx-xxxx
    "70": "TelkomFlexi",  # (area-code)-70xx-xxxx
    "80": "TelkomFlexi",  # (area-code)-80xx-xxxx
    "81": "TelkomFlexi",  # (area-code)-81xx-xxxx
    "68": "TelkomFlexi",  # (area-code)-68xx-xxxx
    "3": "TelkomFlexi",  # (area-code)-3xxx-xxxx

    "61": "Indosat",  # (Area-code)-61xx-xxxx
    "62": "Indosat",  # (Area-code)-62xx-xxxx
    "63": "Indosat",  # (Area-code)-63xx-xxxx
    "90": "Indosat",  # (Area-code)-90xx-xxxx
    "30": "Indosat",  # 021-30xx-xxxx
    "60": "Indosat",  # 021-60xx-xxxx

    "50": "Hepi (Mobile-8)",  # (Area-code)-50xx-xxxx
    "21": "Hepi (Mobile-8)",  # (Area-code)-21xx-xxxx
    "31": "Hepi (Mobile-8)",  # (Area-code)-31xx-xxxx

}

MOBILE_CDMA_PREFIXES = {
    "827": "Ceria",
    "828": "Ceria",

    "881": "Smart",
    "882": "Smart",

    "887": "Smartfren",
    "888": "Smartfren",
    "889": "Smartfren",
}

GSM_PREFIXES = {
    # Indosat
    "814": "Matrix",
    "815": "Matrix / Mentari",
    "816": "Matrix / Mentari",
    "855": "Matrix",

    "858": "Mentari",

    "856": "IM3",
    "857": "IM3",

    # Telkomsel
    "811": "Kartu HALO",
    "812": "Kartu HALO / Simpati",

    "813": "Simpati",
    "821": "Simpati",

    "822": "LOOP",
    "854": "LOOP",

    "823": "Kartu As",
    "851": "Kartu As",
    "852": "Kartu As",
    "853": "Kartu As",

    # PT XL Axiata
    "817": "XL",
    "818": "XL",
    "819": "XL",
    "859": "XL",
    "877": "XL",
    "878": "XL",
    "879": "XL",

    # AXIS, acquired by XL
    "838": "Axis",
    "833": "Axis",
    "832": "Axis",
    "831": "Axis",

    # PT Hutchison CP Telecommunications
    "899": "3",
    "898": "3",
    "897": "3",
    "896": "3",
    "895": "3",
    "894": "3",

}


AREA_CODE = {

    "21": "Jakarta, Tangerang",
    "252": "Lebak",
    "253": "Pandeglang",
    "254": "Cilegon, Serang",

    "22": "Bandung, Cimahi, Sumedang(Jatinagor)",
    "231": "Cirebon",
    "232": "Kuningan",
    "233": "Majalengka",
    "234": "Indramayu",
    "251": "Bogor",
    "260": "Subang",
    "261": "Sumedang",
    "262": "Garut",
    "263": "cianjur",
    "264": "Purwakarta",
    "265": "Banjar, Ciamis, Tasikmalaya",
    "266": "Sukabumi",
    "267": "Karawang",

    '24': "Semarang",
    '271': "Solo, Srage, Karanganyar, Sukoharjo, Boyolali",
    '272': "Klaten",
    '273': "Wonogiri",
    '274': "Yogyakarta",
    '275': "Purworejo",
    '276': "Boyolali",

    '280': "Cilacap",
    '281': "Banyumas, Purbalingga",
    '282': "Cilacap",
    '283': "Tegal, Brebes",
    '284': "Pemalang",
    '285': "Pekalongan, Batang",
    '286': "Banjarnegara, Wonosobo",
    '287': "Kebumen",
    '289': "Bumiayu",

    '291': "Kudus",
    '292': "Grobogan",
    '293': "Magelang, Temanggung",
    '294': "Kendal, Batang(Grinsing)",
    '295': "Pati, Rembang",
    '296': "Blora",
    '297': "Karimun Jawa",
    '298': "Salatiga, Semarang, Boyolali",


    '31': "Surabaya, Gersik, Sidoarjo, Bangkalan",
    '321': "Mojokerto, Jombang",
    '322': "Lamongan",
    '323': "Sampang",
    '324': "Pamekasan",
    '325': "Bawean",
    '326': "Pulau Masalembu",
    '327': "Kangean",
    '328': "Sumenep",

    '331': "Jember",
    '332': "Bondowoso",
    '333': "Banyuwangi",
    '334': "Lumajang",
    '335': "Probolinggo",
    '338': "Situbundo",

    '341': "Malang, Batu",
    '342': "Blitar",
    '343': "Pasuruan",

    '351': "Madiun, Magetan, Ngawi",
    '352': "Ponorogo",
    '353': "Bojonegoro",
    '354': "Kediri",
    '355': "Tulungagung, Trenggalek",
    '356': "Tuban",
    '357': "Pacitan",
    '358': "Nganjuk",

    '361': "Denpasar, Badung, Gianyar, Tabanan",
    '362': "Buleleng",
    '363': "Karangasem",
    '365': "Jembrana",
    '366': "Klungkung, Bangli",
    '368': "Tabanan (Baturiti, Bedugul)",

    '370': "Mataram, Lombok Barat, Lombok Pusat",
    '371': "Sumbawa",
    '372': "Sumbawa Barat",
    '373': "Dompu",
    '374': "Bima",
    '376': "Lombok Timur",
    '379': "Pulau Alor",

    '380': "Kupang",
    '381': "Ende",
    '382': "Sikka",
    '383': "Flores Timur",
    '384': "Ngada",
    '385': "Manggarai",
    '386': "Manggarai Barat",
    '387': "Sumba",
    '388': "North Central Timor, South Central Timor",
    '389': "Belu",

    '401': "Kendari, Konawe",
    '402': "Buton",
    '403': "Muna",
    '404': "Wakatobi",
    '405': "Kolaka",
    '408': "Konawe",
    '409': "Morowali",

    '410': "Pangkajene",
    '411': "Makassar, Maros, Gowa",
    '413': "Bantaeng, Bulukumba",
    '414': "Pulau Selayar",
    '417': "Malino",
    '418': "Takalar",
    '419': "Jeneponto",

    '420': "Enrekang",
    '421': "Pare Pare, Pinrang, Sidenreng Rappang",
    '422': "Majene",
    '423': "Tana Toraja",
    '426': "Mamuju",
    '427': "Barru",
    '428': "Polewali",

    '430': "Minahasa Selatan",
    '431': "Manado, Tomohon, Minahasa, Minahasa Utara",
    '432': "Pulau Sangihe",
    '434': "Bolaang Mongondow",
    '435': "Gorontalo",
    '438': "Bitung",

    '443': "Gorontalo - Pohuwato",

    '450': "Parigi Moutong",
    '451': "Palu",
    '452': "Poso",
    '453': "Toli-Toli",
    '457': "Donggala",
    '458': "Poso(Tentena)",

    '461': "Banggai",
    '462': "Pulau Banggai",
    '464': "Tojo Una-una",

    '471': "Luwu",
    '473': "Luwu Utara",
    '474': "Luwu Timur",

    '481': "Bone",
    '482': "Sinjai",
    '484': "Soppeng",
    '485': "Wajo",

    '511': "Banjarmasin, Banjar, Banjarbaru, Barito Kuala",
    '512': "Tanah Laut",
    '513': "Kapuas, Pulang Pisau",
    '517': "Hulu sungai selatan, Hulu sungai tengah, Tapin",
    '518': "Kotabaru, Tanah Bumbu",
    '519': "Barito Utara",

    '526': "Tabalong, Balangan, Barito Selatan, Barito Timur",
    '527': "Hulu Sungai Utara",
    '528': "Murang Raya",

    '531': "Kotawaringin Timur",
    '532': "Kotawaringin Barat, Sukamara",
    '534': "Ketapang",
    '535': "Kayong Utara",
    '536': "Palangka raya, Katingan",
    '537': "Gunung Mas",
    '539': "Seruyan, Kotawaringin timur",

    '541': "Samarinda, Kutai Kartanegara",
    '542': "Balikpapan, Penajam Paser Utara",
    '543': "Paser",
    '545': "Kutai Barat",
    '548': "Bontang",
    '549': "Kutai Timur",

    '551': "Tarakan, Pulau Bunyu",
    '552': "Bulungan",
    '553': "Malinau",
    '554': "Beray",
    '556': "Nunukan",

    '561': "Pontianak",
    '562': "Sambas, Bengkayang, Singkawang",
    '563': "Landak",
    '564': "Sangau, Sekadau",
    '565': "Sintang",
    '567': "Kapuas Hulu",
    '568': "Melawi",

    '61': "Medan, Binjai, Deli Serdang, Serdang Bedagai(Perbaungan, Pantai Cermin), Langkat",

    '620': "Langkat(Pangkalan Brandan",
    '621': "Tebingtinggi, Serdang Bedagai",
    '622': "Pematang Siantar, Simalungun, Batubara, Serdang bedagai",
    '623': "Asahan, Tanjung Balai, Labuhan Batu(Labuhan Ruku)",
    '624': "Labuhan Batu",
    '625': "Parapat, Samosir",
    '626': "Samosir",
    '627': "Dairi, Pakpak Bharat, Subulussalam",
    '628': "Karo, Deil Serdang (Bandar Baru, Sibolangit)",
    '629': "Aceh Barat Daya",

    '630': "Nias Selatan",
    '631': "Tapanuli pusat, Sibolga",
    '632': "Toba Samosir",
    '633': "Tapanuli Utara, Humbang Hasundutan",
    '634': "Tapanuli Selatan, Padang Sidempuan",
    '635': "Tapanuli Selatan",
    '636': "Mandailing Natal",
    '639': "Nias",

    '641': "Langsa, Aceh Timur, Aceh Tamiang",
    '642': "Gayo Lues",
    '643': "Aceh Pusat",
    '644': "Bireuen",
    '645': "Lhokseumawe, Aceh Utara",
    '646': "Aceh Timur",

    '650': "Siemulue",
    '651': "Banda Aceh, Aceh Besar, Aceh Jaya(Lamno)",
    '652': "Sabang",
    '653': "Pidie",
    '654': "Aceh Jaya",
    '655': "Aceh Barat",
    '656': "Aceh Selatan",
    '657': "Aceh Selatan",
    '658': "Singkil",
    '659': "Aceh Barat Daya",

    '702': "Empat Lawang",

    '711': "Palembang, Ogan Ilir, Banyuasin",
    '712': "Ogan Komering Ilir",
    '713': "Prabumulih, Muara Enim",
    '714': "Musi Banyuasin",
    '715': "Bangka (Belinyu)",
    '716': "Bangka Barat",
    '717': "Bangka, Pangkal Pinang",
    '718': "Bangka pusat, Bangka selatan",
    '719': "Belitung",

    '721': "Bandar Lampung, Lampung Selatan",
    '722': "Tanggamus",
    '723': "Way Kanan",
    '724': "Lampung Utara",
    '725': "Lampung pusat, Lampung Timur, Metro",
    '726': "Tulang Bawang",
    '727': "Lampung Selatan",
    '728': "Lampung Barat",
    '729': "Tanggamus",

    '730': "Lahat, Pagar Alam",
    '731': "Lahat",
    '732': "Rejang Lebong, Kepahiang",
    '733': "Lubuk Linggau, Musi Rawas",
    '734': "Muara Enim",
    '735': "Ogan Komering Ulu",
    '736': "Bengkulu, Seluma",
    '737': "Bengkulu Utara, Muko-muko",
    '739': "Bengkulu Selatan, Kaur",

    '741': "Jambi, Muaro Jambi",
    '742': "Tanjung Jabung Barat",
    '743': "Batanghari",
    '744': "Tebo",
    '745': "Sarolangun",
    '746': "Merangin",
    '747': "Bungo, Tebo(Rimbo Bujang)",
    '748': "Kerinci",

    '751': "Padang, Padang Pariaman, Pariaman, Pesisir Selatan",
    '752': "Agam, Tanah Datar, Limapuluh Koto, Bukittinggi, Padang Panjang, Payakumbuh",
    '753': "Pasaman, Pasaman Barat",
    '754': "Sawahlunto, Sijunjung, Dharmasraya",
    '755': "Solok, Solok Selatan",
    '756': "Pesisir Selatan",
    '757': "Pesisir Selatan",
    '759': "Pulau Mentawai",

    '760': "Kuantan Singingi",
    '761': "Pekanbaru, Pelalawan, Siak, Kampar",
    '762': "Kampar, rokan Hulu",
    '763': "Bengkalis",
    '764': "Siak",
    '765': "Dumai, Bengkalis(Duri), Rokan Hulu(Bagan Batu)",
    '766': "Bengkalis",
    '767': "Rokan Hulu",
    '768': "Indragiri Hilir",
    '769': "Indragiri Hulu",

    '771': "Tanjungpinang, Bintan",
    '772': "Pulan Anambas",
    '773': "Pulau Natuna",
    '776': "Lingga",
    '777': "Great Karimun",
    '778': "Batam",
    '779': "Kundur",

    '901': "Timika",
    '902': "Agats",

    '910': "Banda Naira",
    '911': "Ambon",
    '913': "Namlea",
    '914': "Masohi",
    '916': "Tual",
    '917': "Dobo",
    '918': "Saumlaki",

    '920': "Weda",
    '921': "Ternate",
    '924': "Tobelo",
    '929': "Tidore",

    '951': "Sorong",
    '956': "Kaimana, Fak Fak",

    '963': "Serui",
    '966': "Sarmi",
    '967': "Jayapura",
    '969': "Wamena",

    '971': "Merauke",
    '975': "Tanah Merah (Boven Digoel)",
    '979': "Tembagapura",

    '981': "Biak",
    '983': "Botawa / Serui",
    '984': "Nabire",
    '986': "Manokwari",
}



from setuptools import setup

setup(
    name='id_phonenumbers',
    packages=['id_phonenumbers'],
    version='0.1.6',
    description='Indonesian Phonenumbers Parser',
    license='MIT',
    author='Steven',
    author_email='stvn.bu@gmail.com',
    url='https://github.com/SeiryuZ/id_phonenumbers',
    download_url='https://github.com/SeiryuZ/id_phonenumbers/tarball/0.1.4',
    keywords=['phonenumbers', 'Indonesia'],
    install_requires=['phonenumberslite'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
